@@ -9,15 +9,10 @@ from secrets import token_urlsafe
 from shlex import shlex
 from shutil import move
 from tempfile import mkstemp
-from typing import overload, Dict, Iterator, List, Optional, Tuple, Union
+from typing import Iterator, Optional, Union
 
 from . import db, email, utils
 
-# NOTE: ignore warning about NotImplemented use
-__import__('warnings').filterwarnings(
-    'ignore', 'NotImplemented', DeprecationWarning, 'yaenv'
-)
-
 
 class EnvError(Exception):
     """Exception class representing a dotenv error."""
@@ -39,7 +34,7 @@ class EnvVar:
     key: str
     value: str
 
-    def __new__(cls, line: str) -> Optional[EnvVar]:  # type: ignore[misc]
+    def __new__(cls, line: str) -> Optional[EnvVar]:  # type: ignore
         """
         Parse a line and return a new instance or ``None``.
 
@@ -51,8 +46,8 @@ class EnvVar:
         Returns
         -------
         Optional[EnvVar]
-            Returns a new ``EnvVar`` if all went well, or ``None``
-            if the line doesn't contain a variable declaration.
+            A new ``EnvVar`` if all went well, or ``None`` if
+            the line doesn't contain a variable declaration.
 
         Raises
         ------
@@ -142,6 +137,22 @@ class EnvVar:
         yield self.key
         yield self.value
 
+    def __len__(self) -> int:
+        """
+        Return a number which represents the state of the ``EnvVar``.
+
+        Returns
+        -------
+        int
+            ``0`` if the ``EnvVar`` is ``None``, ``1``
+            if the value is blank, or ``2`` otherwise.
+        """
+        if self is None:
+            return 0
+        if not self.value:
+            return 1
+        return 2
+
     def __str__(self) -> str:  # pragma: no cover
         """
         Return the variable as a string.
@@ -215,7 +226,7 @@ class Env(PathLike):
         EnvError
             If the environment variable is missing.
         """
-        value = self.ENV.get(key, self.vars.get(key))
+        value = self.vars.get(key)
         if value is None:
             raise EnvError(f"Missing environment variable: '{key}'")
         return value
@@ -255,13 +266,13 @@ class Env(PathLike):
         else:
             self._replace(key, None)
 
-    def __iter__(self) -> Iterator[Tuple[str, str]]:
+    def __iter__(self) -> Iterator[tuple[str, str]]:
         """
         Iterate through the entries in the dotenv file.
 
         Returns
         -------
-        Iterator[Tuple[str, str]]
+        Iterator[tuple[str, str]]
             An iterator of key-value pairs.
         """
         yield from self.vars.items()
@@ -329,14 +340,14 @@ class Env(PathLike):
         return f"Env('{self.envfile}')"
 
     @cached_property
-    def vars(self) -> Dict[str, str]:
-        """`Dict[str, str]` : Get the environment variables as a ``dict``."""
-        def _sub_callback(match):  # type: ignore[no-untyped-def]
-            return {**self.ENV, **result}.get(match.group(1), '')
+    def vars(self) -> dict[str, str]:
+        """`dict[str, str]` : Get the environment variables as a ``dict``."""
+        def _sub_callback(match):  # type: ignore
+            return (self.ENV | result).get(match.group(1), '')  # type: ignore
 
         with open(self.envfile, 'r') as f:
-            envvars = list(filter(None.__ne__, map(EnvVar, f.readlines())))
-            result = dict(envvars)  # type: ignore[arg-type]
+            envvars = list(filter(EnvVar.__len__, map(EnvVar, f.readlines())))
+            result = dict(envvars)  # type: ignore
 
         # substitute variables that can be interpolated
         posix = regex(r'\$\{([^}].*)?\}')
@@ -347,13 +358,7 @@ class Env(PathLike):
 
     def setenv(self) -> None:
         """Add the variables defined in the dotenv file to :os:`environ`."""
-        self.ENV.update(self.vars)
-
-    @overload
-    def get(self, key: str, default: str) -> str: ...
-
-    @overload
-    def get(self, key: str, default: None = None) -> Optional[str]: ...
+        self.ENV |= self.vars  # type: ignore
 
     def get(self, key: str, default: Optional[str] = None) -> Optional[str]:
         """
@@ -378,12 +383,6 @@ class Env(PathLike):
         """
         return self.ENV.get(key, self.vars.get(key) or default)
 
-    @overload
-    def bool(self, key: str, default: bool) -> bool: ...
-
-    @overload
-    def bool(self, key: str, default: None = None) -> Optional[bool]: ...
-
     def bool(self, key: str, default: Optional[bool] = None) -> Optional[bool]:
         """
         Return an environment variable as a ``bool``, or a default value.
@@ -419,12 +418,6 @@ class Env(PathLike):
             return False
         raise EnvError(f"Invalid boolean value: '{value}'")
 
-    @overload
-    def int(self, key: str, default: int) -> int: ...
-
-    @overload
-    def int(self, key: str, default: None = None) -> Optional[int]: ...
-
     def int(self, key: str, default: Optional[int] = None) -> Optional[int]:
         """
         Return an environment variable as an ``int``, or a default value.
@@ -459,12 +452,6 @@ class Env(PathLike):
         except ValueError:
             raise EnvError(f"Invalid integer value: '{value}'")
 
-    @overload
-    def float(self, key: str, default: float) -> float: ...
-
-    @overload
-    def float(self, key: str, default: None = None) -> Optional[float]: ...
-
     def float(self, key: str, default:
               Optional[float] = None) -> Optional[float]:
         """
@@ -500,15 +487,8 @@ class Env(PathLike):
         except ValueError:
             raise EnvError(f"Invalid numerical value: '{value}'")
 
-    @overload
-    def list(self, key: str, default: List, separator: str = ...) -> List: ...
-
-    @overload
-    def list(self, key: str, default: None = None,
-              separator: str = ...) -> Optional[List]: ...
-
-    def list(self, key: str, default: Optional[List] = None,
-             separator: str = ',') -> Optional[List]:
+    def list(self, key: str, default: Optional[list] = None,
+             separator: str = ',') -> Optional[list]:
         """
         Return an environment variable as a ``list``, or a default value.
 
@@ -516,14 +496,14 @@ class Env(PathLike):
         ----------
         key : str
             The name of the variable.
-        default : Optional[List]
+        default : Optional[list]
             The default value.
         separator : str
             The separator to use when splitting the list.
 
         Returns
         -------
-        Optional[List]
+        Optional[list]
             The ``list`` value of the variable or the ``default`` value.
 
         Examples
@@ -536,12 +516,6 @@ class Env(PathLike):
             return default
         return value.split(separator)
 
-    @overload
-    def db(self, key: str, default: str) -> db.DBConfig: ...
-
-    @overload
-    def db(self, key: str, default: None = None) -> Optional[db.DBConfig]: ...
-
     def db(self, key: str, default:
            Optional[str] = None) -> Optional[db.DBConfig]:
         """
@@ -576,13 +550,6 @@ class Env(PathLike):
         except Exception as e:
             raise EnvError(f"Invalid database URL: '{value}'") from e
 
-    @overload
-    def email(self, key: str, default: str) -> email.EmailConfig: ...
-
-    @overload
-    def email(self, key: str, default: None = None
-              ) -> Optional[email.EmailConfig]: ...
-
     def email(self, key: str, default:
               Optional[str] = None) -> Optional[email.EmailConfig]:
         """
