@@ -1,17 +1,11 @@
 """Useful utilities."""
 
-from importlib import import_module
-from sys import version_info
 from typing import Any
 
 _truthy = ('1', 'on', 'y', 'yes', 'true')
 
 _falsy = ('', '0', 'off', 'n', 'no', 'false')
 
-cached_property = import_module(
-    'functools' if version_info >= (3, 8) else 'cached_property'
-).cached_property
-
 
 def is_truthy(arg: Any) -> bool:
     """
@@ -61,4 +55,4 @@ def is_falsy(arg: Any) -> bool:
     return str(arg).lower() in _falsy
 
 
-__all__ = ['is_truthy', 'is_falsy', 'cached_property']
+__all__ = ['is_truthy', 'is_falsy']
